#!/usr/bin/perl -w

package Source::Repository::Mass::ALTLinuxBackport;

use strict;
use warnings;
#use Carp;

use Source::Repository::Mass;
use RPM::Source::Convert::ALTLinuxBackport;
use Source::Repository::Matcher;
use Source::Repository::Matcher::DistroMap;
use Source::Repository::Mass::Transform;

our @ISA = qw/Source::Repository::Mass/;
our $backport_suffix;
our $destbranch='p6';

$Source::Repository::Mass::Transform::suppress_rename=1;
$Source::Repository::Mass::strategy = 'newer';

$DistroMap::default_originrepo='altlinux';
$DistroMap::default_originbranch='sisyphus';
$DistroMap::default_destrepo='altlinux';

sub new {
    my $class = shift;
    $destbranch=&RPM::Source::Convert::ALTLinuxBackport::_suffix2destbranch($backport_suffix) if $backport_suffix;
    $DistroMap::default_destbranch=$destbranch;
    return $class->SUPER::new(@_);
};

sub process_options_hook {
    my ($self)=@_;
    $backport_suffix=&RPM::Source::Convert::ALTLinuxBackport::_destbranch2suffix($DistroMap::default_destbranch) unless $backport_suffix;
}

sub cmp_origin_dest {
    my ($self,$origin,$dest) =@_;
    #return &RPM::Source::Convert::ALTLinuxBackport::__backport_cmp_origin_dest($origin,$dest,$backport_suffix,$Source::Repository::Mass::verbose);
    return &__backport_cmp_origin_dest($origin,$dest,$backport_suffix,$Source::Repository::Mass::verbose);
}

# todo: REMOVE on R::S::C upgrade
sub __backport_cmp_origin_dest {
    my ($origin,$dest,$backport_suffix,$verbose) =@_;
    return 1 unless $dest;
    return -1 unless $origin;
    my $originversion=$origin->version;
    my $originrelease=$origin->release;
    my $destversion=$dest->version;
    my $destrelease=$dest->release;
    my $autoportsrelease=&RPM::Source::Convert::ALTLinuxBackport::_nextrel_altbackport_raw($originrelease, $backport_suffix);
    my $cmp = $originversion cmp $destversion;
    if ($cmp!=0) {
	$cmp=RPM::evrcmp($originversion,$destversion);
	print STDERR "version: $originversion rpmcmp $destversion = $cmp\n" if $verbose>1;
    }
    return $cmp if $cmp !=0;
    return 0 if $destrelease eq $autoportsrelease or $destrelease eq $originrelease;
    # Binary "cmp" returns -1, 0, or 1 depending on whether the left argument
    # is stringwise less than, equal to, or greater than the right argument.
    $cmp=RPM::evrcmp($originrelease,$destrelease);
    print STDERR "$originrelease rpmcmp $destrelease = $cmp\n" if $verbose>1;
    return $cmp if $cmp <= 0;
    $cmp=RPM::evrcmp($autoportsrelease,$destrelease);
    print STDERR "$autoportsrelease rpmcmp $destrelease = $cmp\n" if $verbose>1;
    return $cmp;
}



1;
