#!/usr/bin/perl -w

package Source::Repository::Mass::Transform::Embedded;

use strict;
use warnings;
use Source::Repository::Mass::Transform;

our @ISA = qw(Source::Repository::Mass::Transform);
our $embedded_class='RPM::Source::Transform';

push @Source::Repository::Mass::EXT_OPTS, @RPM::Source::Transform::LONGOPT, @RPM::Source::Transform::EXT_OPTS;

sub process_options_hook {
    my ($self)=@_;
    $RPM::Source::Transform::verbose=$Source::Repository::Mass::verbose;
    $self->{-transform}=$embedded_class->new(-embedded=>1);
}

sub process_pair {
    my ($self,$pkgpair,$transaction_name,$transaction_count)=@_;
    my ($originname, $destname)=($pkgpair->originname,$pkgpair->destname);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    if (not $origin) {
	print STDERR "ERROR: origin file for $originname not found.\n";
	return;
    }
    my $converter=$self->{-transform};
    my $converter_opt=$converter->mk_opt();
    $converter_opt->{-rename}=$destname if $destname ne $originname and not $Source::Repository::Mass::Transform::suppress_rename;

    my $OUTDIR = $Source::Repository::Mass::OUTDIR;
    $converter_opt->{-outputdir} = defined($transaction_name) ? "$OUTDIR/$transaction_name.transaction/".('0' x (5-length($transaction_count))).$transaction_count : $OUTDIR;

    my ($spec,$parent)=$self->get_spec_parent($pkgpair,$converter,$converter_opt);
    #$self->process_pair_hook($pkgpair, $converter_opt, $spec, $parent);
    $converter->transform_once($spec,$parent,$converter_opt);

    print "---*---\n";
}

sub get_spec_parent {
    my ($self,$pkgpair,$converter,$converter_opt)=@_;
    my ($spec,$parent);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    $spec=$converter->get_spec($self->{-originrepo}->pkg4rpmeditor($origin)) if $origin;
    $parent=$converter->get_parent($self->{-destrepo}->pkg4rpmeditor($dest)) if $dest;
    return ($spec,$parent);
}

1;
