#!/usr/bin/perl -w

package Source::Repository::Matcher;

use Carp;
use strict;
use warnings;

require Exporter;

our @ISA = qw(Exporter);
our @EXPORT = qw/%ORIGIN2DESTMAP/;

our %ORIGIN2DESTMAP=();
my %DEST2ORIGINMAP=();

our @DEST2ORIGIN=(\&__dest2origin);
our @ORIGIN2DEST=(\&__origin2dest);

sub new {
    my $class = shift;
    my $self = {
	@_
    };
    bless $self, $class;

    # TODO: handle both?
    %DEST2ORIGINMAP=reverse (%ORIGIN2DESTMAP);

    return $self;
}

sub new_pair {
    my ($self,$input)=@_;
    Carp::confess "Source::Repository::Matcher::new_pair: undefined input" unless defined $input;
    my ($destname, $originname, $dest, $origin);
    if ($self->{-destmode}) {
	my $pkg=$self->{-destrepo}->pkg($input);
	$destname=$pkg ? $pkg->name : $input;
	$originname=&__try_mappers($self,$destname,\@DEST2ORIGIN);
	$origin = $self->{-originrepo}->name2pkg($originname);
	$dest = $pkg;
    } else {
	my $pkg=$self->{-originrepo}->pkg($input);
	$originname=$pkg ? $pkg->name : $input;
	$destname=&__try_mappers($self,$originname,\@ORIGIN2DEST);
	$origin = $pkg;
	$dest = $self->{-destrepo}->name2pkg($destname);
    }
    return Source::Package::Pair->new(
	-originname => $originname,
	-destname => $destname,
	-origin => $origin,
	-dest => $dest,
	);
}

# prototype -- to remove if not used
sub __prototype_name2pair {
    my ($self,$name)=@_;
    Carp::confess "Source::Repository::Matcher::new_pair: undefined name" unless defined $name;
    my $destname=$name;
    my $originname=$name;
    if ($self->{-destmode}) {
	$originname = &__try_mappers($self,$name,\@DEST2ORIGIN);
    } else {
	$destname = &__try_mappers($self,$name,\@ORIGIN2DEST);
    }
    return Source::Package::Pair->new(
	-originname => $originname,
	-destname => $destname,
	-origin => $self->{-originrepo}->name2pkg($originname),
	-dest => $self->{-destrepo}->name2pkg($destname),
	);
}

sub __origin2dest { 
    my ($self,$name)=@_;
    return $ORIGIN2DESTMAP{$name};
}

sub __dest2origin { 
    my ($self,$name)=@_;
    return $DEST2ORIGINMAP{$name};
}

sub __try_mappers {
   my ($self,$name,$mappers)=@_;
   foreach my $mapper (@$mappers) {
       my $newname=&$mapper($self,$name);
       if (defined $newname) {
	   return $newname;
       }
   }
   return $name;
}

package Source::Package::Pair;

sub new {
    my $class=shift;
    my $self = {
	@_,
    };
    #print STDERR "Source::Package::Pair: new: ",join(' ',@_),"\n";
    bless($self,$class);
}

sub destname {
    my ($self)=@_;
    return $self->{-destname};
}

sub originname {
    my ($self)=@_;
    return $self->{-originname};
}

sub origin {
    my ($self)=@_;
    return $self->{-origin};
}

sub dest {
    my ($self)=@_;
    return $self->{-dest};
}

1;
