package Source::Repository::RPM;

use strict;
use warnings;
use Carp;
use RPM::Header;

use Source::Repository;

our @ISA=qw/Source::Repository/;

sub init_hook {
    my ($self)=@_;
    $self->{-rpmfindsub} ||= \&Source::Repository::RPM::find_highest_rpm;
}

sub pkg {
    return &name2pkg;
}

sub name2pkg {
    my ($self,$name)=@_;
    my $rh=&{$self->{-rpmfindsub}}($name,@{$self->{-path}});
    return unless $rh;
    return Source::Package->new(
	-name => $rh->{NAME},
	-version => $rh->{VERSION},
	-release => $rh->{RELEASE},
	-epoch => $rh->{EPOCH},
	-file => $rh->source_name,
	);
}

sub pkg4rpmeditor {
    my ($self, $pkg)=@_;
    return [ SOURCERPM => $pkg->file];
}

#------------------------------------------
#    protected utilities
#------------------------------------------

sub find_highest_rpm {
    my $name=shift;
    my $cur_href;
    for my $path (@_) {
      PATH:
	for my $rpmfile (reverse(glob "$path/$name-*.src.rpm")) {
#	print STDERR "trying $rpmfile for $name\n";
	    my $href = new RPM::Header $rpmfile;
	    if ($name eq $href->{NAME}) {
		if (not $cur_href or $cur_href->cmpver($href)<0) {
		    $cur_href=$href;
		}
		# assume 1 rpm per name; false for jpp TODO:option!!!
		last PATH;
	    }
	}
    }
    return $cur_href;
}

sub find_first_rpm {
    my $name=shift;
    for my $path (@_) {
	for my $rpmfile (reverse(glob "$path/$name-*.src.rpm")) {
#	print STDERR "trying $rpm for $name\n";
	    my $href = new RPM::Header $rpmfile;
	    if ($name eq $href->{NAME}) {
		# assume 1 rpm per name; false for jpp TODO:option!!!
		return $href;
	    }
	}
    }
    return;
}


#------------------------------------------
#    private utilities
#------------------------------------------

1;
